@@ -3,10 +3,15 @@ package InfoSys::FreeDB::Entry::Track;
 use 5.006;
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 
 # Package version
-our ($VERSION) = '$Revision: 0.10 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.11 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -263,4 +268,3 @@ sub set_title {
 sub write_fh {
 }
 
-1;
