@@ -4,6 +4,7 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use InfoSys::FreeDB::Response qw(:line_parse);
 
@@ -25,7 +26,11 @@ our %ALLOW_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.10 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.11 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -578,4 +583,3 @@ sub unshift_match {
     unshift( @{ $self->{InfoSys_FreeDB_Response_Query}{match} }, @_ );
 }
 
-1;
