@@ -4,6 +4,7 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 
 our $STAT_DB_ENTRIES_RX = '^\s*database\s+entries\s*:\s*(\S+)';
@@ -27,7 +28,11 @@ our $STAT_USERS_CUR_RX = '^\s*current\s+users\s*:\s*(\S+)';
 our $STAT_USERS_MAX_RX = '^\s*max\s+users\s*:\s*(\S+)';
 
 # Package version
-our ($VERSION) = '$Revision: 0.10 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.11 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -627,4 +632,3 @@ sub set_users_max {
     $self->{InfoSys_FreeDB_Response_Stat}{users_max} = $val;
 }
 
-1;
