@@ -4,6 +4,7 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 
 # Used by _initialize
@@ -12,7 +13,11 @@ our %DEFAULT_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.10 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.11 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -266,4 +271,3 @@ sub set_message_text {
     $self->{InfoSys_FreeDB_Response_Whom}{message_text} = $val;
 }
 
-1;
