@@ -3,6 +3,7 @@ package InfoSys::FreeDB::Site;
 use 5.006;
 use strict;
 use warnings;
+use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 
 # Used by _initialize
@@ -11,7 +12,11 @@ our %DEFAULT_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.10 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.11 $' =~ /\$Revision:\s+([^\s]+)/;
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -388,4 +393,3 @@ sub set_site {
     $self->{InfoSys_FreeDB_Site}{site} = $val;
 }
 
-1;
